@@ -1,13 +1,10 @@
 import json
 import logging
-import os
 from datetime import datetime, timezone
 from importlib import resources
 
 import fastjsonschema
-
-from metaphor import common
-from metaphor.common.metadata_change_event import (
+from metaphor.models.metadata_change_event import (
     Dashboard,
     Dataset,
     EventHeader,
@@ -16,6 +13,8 @@ from metaphor.common.metadata_change_event import (
     Person,
 )
 
+from metaphor import models
+
 logger = logging.getLogger()
 logger.setLevel(logging.INFO)
 
@@ -23,16 +22,14 @@ logger.setLevel(logging.INFO)
 class EventUtil:
     """Event utilities"""
 
-    kinesis_tenant = os.environ.get("KINESIS_TENANT", "default")
-
-    with resources.open_text(common, "metadata_change_event.json") as f:
+    with resources.open_text(models, "metadata_change_event.json") as f:
         validate = fastjsonschema.compile(json.load(f))
 
     @staticmethod
     def _build_event() -> MetadataChangeEvent:
         """Create an MCE"""
         event = MetadataChangeEvent()
-        event.tenant = EventUtil.kinesis_tenant
+        event.tenant = "default"
         event.event_header = EventHeader()
         event.event_header.time = datetime.now(timezone.utc)
         return event
