@@ -2,19 +2,28 @@ import asyncio
 import logging
 from abc import ABC, abstractmethod
 from dataclasses import dataclass
-from typing import List, Optional
+from typing import List, Optional, Type
 
 from dataclasses_json import dataclass_json
+from metaphor.models.metadata_change_event import MetadataChangeEvent
 from smart_open import open
 
-from .api import IngestionApi, IngestionApiConfig
-from .kinesis import Kinesis, KinesisConfig
-from .metadata_change_event import MetadataChangeEvent
+from .api_sink import ApiSink, ApiSinkConfig
+from .file_sink import FileSink, FileSinkConfig
 
 logger = logging.getLogger()
 logger.setLevel(logging.INFO)
 
 
+@dataclass_json
+@dataclass
+class OutputConfig:
+    """Config for where to output the data"""
+
+    api: Optional[ApiSinkConfig] = None
+    file: Optional[FileSinkConfig] = None
+
+
 @dataclass_json
 @dataclass
 class RunConfig:
@@ -23,8 +32,7 @@ class RunConfig:
     All subclasses should add the @dataclass_json & @dataclass decorators
     """
 
-    kinesis: Optional[KinesisConfig]
-    api: Optional[IngestionApiConfig]
+    output: OutputConfig
 
     @classmethod
     def from_json_file(cls, path: str) -> "RunConfig":
@@ -36,6 +44,11 @@ class RunConfig:
 class BaseExtractor(ABC):
     """Base class for metadata extractors"""
 
+    @staticmethod
+    @abstractmethod
+    def config_class() -> Type[RunConfig]:
+        """Returns the corresponding config class"""
+
     def run(self, config: RunConfig) -> bool:
         """Callable function to extract metadata and send/post messages"""
         logger.info("Starting extractor {}".format(self.__class__.__name__))
@@ -45,11 +58,12 @@ class BaseExtractor(ABC):
         logger.info("Fetched {} entities".format(len(events)))
 
         no_error = True
-        if config.kinesis is not None:
-            no_error = no_error & Kinesis(config.kinesis).send_messages(events)
 
-        if config.api is not None:
-            no_error = no_error & IngestionApi(config.api).send_messages(events)
+        if config.output.api is not None:
+            no_error = no_error & ApiSink(config.output.api).sink(events)
+
+        if config.output.file is not None:
+            no_error = no_error & FileSink(config.output.file).sink(events)
 
         logger.info("Execution finished")
         return no_error
