@@ -1,3 +1,4 @@
+import base64
 import json
 import logging
 from dataclasses import dataclass
@@ -6,11 +7,8 @@ from typing import Dict, List
 from google.auth.transport.requests import Request
 from google.oauth2.credentials import Credentials
 from googleapiclient.discovery import build
-from smart_open import open
-
-from metaphor.common.event_util import EventUtil
-from metaphor.common.extractor import BaseExtractor, RunConfig
-from metaphor.common.metadata_change_event import (
+from googleapiclient.errors import HttpError
+from metaphor.models.metadata_change_event import (
     EntityType,
     Group,
     GroupID,
@@ -20,6 +18,11 @@ from metaphor.common.metadata_change_event import (
     PersonLogicalID,
     PersonProperties,
 )
+from smart_open import open
+
+from metaphor.common.entity_id import EntityId
+from metaphor.common.event_util import EventUtil
+from metaphor.common.extractor import BaseExtractor, RunConfig
 
 logger = logging.getLogger()
 logger.setLevel(logging.INFO)
@@ -43,19 +46,37 @@ class GoogleDirectoryRunConfig(RunConfig):
     token_file: str
 
 
+def build_directory_service(config: GoogleDirectoryRunConfig):
+    with open(config.token_file) as fin:
+        credential = Credentials.from_authorized_user_info(json.load(fin), SCOPES)
+
+    # If token expired, try refresh it.
+    if not credential.valid:
+        if credential.expired and credential.refresh_token:
+            credential.refresh(Request())
+        else:
+            raise InvalidTokenError()
+
+    return build("admin", "directory_v1", credentials=credential)
+
+
 class GoogleDirectoryExtractor(BaseExtractor):
     """Google Directory metadata extractor"""
 
+    @staticmethod
+    def config_class():
+        return GoogleDirectoryRunConfig
+
     def __init__(self):
         self._users: List[Person] = []
         self._groups: List[Group] = []
 
     async def extract(self, config: RunConfig) -> List[MetadataChangeEvent]:
-        assert isinstance(config, GoogleDirectoryRunConfig)
+        assert isinstance(config, GoogleDirectoryExtractor.config_class())
 
         logger.info("Fetching metadata from Google Directory")
 
-        service = self._get_directory_service(config)
+        service = build_directory_service(config)
 
         # get all users
         results = (
@@ -64,7 +85,8 @@ class GoogleDirectoryExtractor(BaseExtractor):
         users = results.get("users", [])
 
         for user in users:
-            self._parse_user(user)
+            photo = self._get_photo(service, user["id"])
+            self._parse_user(user, photo)
 
         # get all groups
         results = (
@@ -90,39 +112,36 @@ class GoogleDirectoryExtractor(BaseExtractor):
             EventUtil.build_group_event(p) for p in self._groups
         ]
 
-    @staticmethod
-    def _get_directory_service(config: GoogleDirectoryRunConfig):
+    def _get_photo(self, service, user_id) -> Dict:
+        try:
+            return service.users().photos().get(userKey=user_id).execute()
+        except HttpError as error:
+            if error.resp.status != 404:
+                raise error
 
-        with open(config.token_file) as fin:
-            credential = Credentials.from_authorized_user_info(json.load(fin), SCOPES)
+            # user has no photo
+            return {}
 
-        # If token expired, try refresh it.
-        if not credential.valid:
-            if credential.expired and credential.refresh_token:
-                credential.refresh(Request())
-            else:
-                raise InvalidTokenError()
-
-        return build("admin", "directory_v1", credentials=credential)
-
-    def _parse_user(self, user: Dict) -> None:
+    def _parse_user(self, user: Dict, photo: Dict) -> None:
         person = Person()
-        person.entity_type = EntityType.PERSON
         person.logical_id = PersonLogicalID()
         person.logical_id.email = user["primaryEmail"]
 
         person.properties = PersonProperties()
         person.properties.first_name = user["name"]["givenName"]
         person.properties.last_name = user["name"]["familyName"]
-        # ignore the private avatar URL until [ch969] is fixed, login user can still get this from OKTA
-        # if "thumbnailPhotoUrl" in user:
-        #    person.avatar_url = user["thumbnailPhotoUrl"]
+
+        if "mimeType" and "photoData" in photo:
+            # Convert URL-safe to standard base64 encoding to form a Data URL
+            data = base64.standard_b64encode(
+                base64.urlsafe_b64decode(photo["photoData"])
+            ).decode("utf-8")
+            person.properties.avatar_url = f'data:{photo["mimeType"]};base64,{data}'
 
         self._users.append(person)
 
     def _parse_group(self, group: Dict, members: List[Dict]) -> None:
         grp = Group()
-        grp.entity_type = EntityType.GROUP
         grp.logical_id = GroupID()
         grp.logical_id.group_name = group["name"]
         grp.group_info = GroupInfo()
@@ -134,12 +153,11 @@ class GoogleDirectoryExtractor(BaseExtractor):
         for member in members:
             # TODO: get subgroups instead of derived members
             if member["type"] == "USER":
-                user = PersonLogicalID()
-                user.email = member["email"]
+                user = EntityId(EntityType.PERSON, PersonLogicalID(member["email"]))
 
                 if member["role"] in ["OWNER", "MANAGER"]:
-                    grp.group_info.admins.append(user)
+                    grp.group_info.admins.append(str(user))
                 else:
-                    grp.group_info.members.append(user)
+                    grp.group_info.members.append(str(user))
 
         self._groups.append(grp)
