@@ -12,14 +12,11 @@ except ImportError:
     print("Please install metaphor[postgresql] extra\n")
     raise
 
-from metaphor.common.extractor import BaseExtractor, RunConfig
-from metaphor.common.metadata_change_event import (
-    AspectType,
+from metaphor.models.metadata_change_event import (
     DataPlatform,
     Dataset,
     DatasetLogicalID,
     DatasetSchema,
-    EntityType,
     ForeignKey,
     MaterializationType,
     MetadataChangeEvent,
@@ -28,6 +25,8 @@ from metaphor.common.metadata_change_event import (
     SQLSchema,
 )
 
+from metaphor.common.extractor import BaseExtractor, RunConfig
+
 logger = logging.getLogger()
 logger.setLevel(logging.INFO)
 
@@ -47,13 +46,17 @@ class PostgresqlRunConfig(RunConfig):
 class PostgresqlExtractor(BaseExtractor):
     """PostgreSQL metadata extractor"""
 
+    @staticmethod
+    def config_class():
+        return PostgresqlRunConfig
+
     _ignored_dbs = ["template0", "template1", "rdsadmin"]
 
     def __init__(self):
         self._datasets: Dict[str, Dataset] = {}
 
     async def extract(self, config: RunConfig) -> List[MetadataChangeEvent]:
-        assert isinstance(config, PostgresqlRunConfig)
+        assert isinstance(config, PostgresqlExtractor.config_class())
 
         platform = DataPlatform.REDSHIFT if config.redshift else DataPlatform.POSTGRESQL
         logger.info(f"Fetching metadata from {platform} host {config.host}")
@@ -198,13 +201,11 @@ class PostgresqlExtractor(BaseExtractor):
         full_name: str, table_type: str, platform: DataPlatform, description: str
     ) -> Dataset:
         dataset = Dataset()
-        dataset.entity_type = EntityType.DATASET
         dataset.logical_id = DatasetLogicalID()
         dataset.logical_id.platform = platform
         dataset.logical_id.name = full_name
 
         dataset.schema = DatasetSchema()
-        dataset.schema.aspect_type = AspectType.DATASET_SCHEMA
         dataset.schema.schema_type = SchemaType.SQL
         dataset.schema.description = description
         dataset.schema.fields = []
