@@ -8,16 +8,16 @@ except ImportError:
     print("Please install metaphor[slack] extra\n")
     raise
 
-from metaphor.common.event_util import EventUtil
-from metaphor.common.extractor import BaseExtractor, RunConfig
-from metaphor.common.metadata_change_event import (
-    EntityType,
+from metaphor.models.metadata_change_event import (
     MetadataChangeEvent,
     Person,
     PersonLogicalID,
     PersonSlackProfile,
 )
 
+from metaphor.common.event_util import EventUtil
+from metaphor.common.extractor import BaseExtractor, RunConfig
+
 logging.basicConfig(level=logging.INFO)
 
 logger = logging.getLogger()
@@ -34,21 +34,40 @@ class SlackRunConfig(RunConfig):
     # Include deleted users
     include_deleted: bool = False
 
+    # Include restricted (guest) users
+    include_restricted: bool = False
+
     # Exclude the default Slack bot, which is weirdly not marked as "is_bot".
     excluded_ids: FrozenSet[str] = frozenset(["USLACKBOT"])
 
 
+def list_all_users(config: SlackRunConfig) -> List[Dict]:
+    users = []
+    next_cursor = None
+    client = WebClient(token=config.oauth_token)
+    while True:
+        response = client.users_list(limit=config.page_size, cursor=next_cursor)
+        users.extend(response["members"])
+        next_cursor = response["response_metadata"].get("next_cursor", "")
+        if next_cursor == "":
+            return users
+
+
 class SlackExtractor(BaseExtractor):
     """Slack directory extractor"""
 
+    @staticmethod
+    def config_class():
+        return SlackRunConfig
+
     async def extract(self, config: RunConfig) -> List[MetadataChangeEvent]:
-        assert isinstance(config, SlackRunConfig)
+        assert isinstance(config, SlackExtractor.config_class())
 
         logger.info("Fetching directory data from Slack")
 
         persons = []
-        for user in self.list_all_users(config):
-            # Filter out bots & delete users, and specific IDs based on config
+        for user in list_all_users(config):
+            # Filter out users based on the config
             if user["is_bot"]:
                 continue
 
@@ -58,6 +77,11 @@ class SlackExtractor(BaseExtractor):
             if user["id"] in config.excluded_ids:
                 continue
 
+            if (
+                user["is_restricted"] or user["is_ultra_restricted"]
+            ) and not config.include_restricted:
+                continue
+
             slack_profile = PersonSlackProfile(
                 slack_id=user["id"],
                 team_id=user["team_id"],
@@ -72,21 +96,9 @@ class SlackExtractor(BaseExtractor):
 
             persons.append(
                 Person(
-                    entity_type=EntityType.PERSON,
                     logical_id=PersonLogicalID(email=email),
                     slack_profile=slack_profile,
                 )
             )
 
         return [EventUtil.build_person_event(p) for p in persons]
-
-    def list_all_users(self, config: SlackRunConfig) -> List[Dict]:
-        users = []
-        next_cursor = None
-        while True:
-            client = WebClient(token=config.oauth_token)
-            response = client.users_list(limit=config.page_size, cursor=next_cursor)
-            users.extend(response["members"])
-            next_cursor = response["response_metadata"].get("next_cursor", "")
-            if next_cursor == "":
-                return users
